@@ -235,3 +235,32 @@ function s090_skybase.cutsceneplayer_108_end()
     Game.PlayCutsceneOnScenarioLoaded("cutsceneplayer_108", true, true, true, false, false, "", "", 0, 0, 0)
   end
 end
+
+function s090_skybase.OnUsablePrepareUse(actor)
+  Scenario.DisableGlobalTeleport(actor)
+end
+
+function s090_skybase.OnUsableCancelUse(actor)
+  Scenario.ResetGlobalTeleport(actor)
+end
+
+function s090_skybase.OnUsableUse(actor)
+  Scenario.SetTeleportalUsed(actor)
+end
+
+function s090_skybase.CheckArtifactsObtained()
+  if RandomizerPowerup.GetItemAmount("ITEM_METROIDNIZATION") == 0 then
+    local oActor = Game.GetActor("accesspoint_000")
+    if oActor ~= nil then
+      oActor.USABLE:ActiveDialogue("DIAG_ADAM_SHIP_2")
+    end
+  end
+end
+
+function s090_skybase.OnEnter_AP_10()
+  s090_skybase.CheckArtifactsObtained()
+end
+
+function s090_skybase.OnExit_AP_10()
+  s090_skybase.CheckArtifactsObtained()
+end
